@@ -1,16 +1,16 @@
-# Comparative modeling by the automodel class
+# Comparative modeling by the AutoModel class
 
 from modeller import *
 
-from modeller.automodel import *    # Load the automodel class
+from modeller.automodel import *    # Load the AutoModel class
 
-env = environ()  # create a new MODELLER environment to build this model in
+env = Environ()  # create a new MODELLER environment to build this model in
 log.verbose()    # request verbose output
 
 # directories for input atom files
 env.io.atom_files_directory = ['.', '../atom_files']
 
-a = loopmodel(env,
+a = LoopModel(env,
               alnfile  = 'alignment.ali',      # alignment filename
               knowns   = '5fd1',               # codes of the templates
               sequence = '1fdx',               # code of the target
