@@ -1,12 +1,12 @@
-# Example for: alignment.consensus()
+# Example for: Alignment.consensus()
 
 # This will read 2 sequences and prepare a consensus alignment
 # from many different pairwise alignments.
 
 from modeller import *
-env = environ()
+env = Environ()
 
-aln = alignment(env)
+aln = Alignment(env)
 aln.append(file='toxin.ali', align_codes=('2ctx', '2abx'))
 aln.consensus(gap_penalties_1d=(0, 0.4), align_block=1)
 aln.write(file='toxin-seq.pap', alignment_format='PAP')
