@@ -1,10 +1,10 @@
 """Classes to build all-atom model(s) using template information"""
 
-from modeller.automodel.automodel import automodel
+from modeller.automodel.automodel import AutoModel
 
 __docformat__ = "epytext en"
 
-class allhmodel(automodel):
+class AllHModel(AutoModel):
     """Automatically build all-atom model(s) using template information"""
 
     toplib = '${LIB}/top_allh.lib'
@@ -12,11 +12,15 @@ class allhmodel(automodel):
     def __init__(self, env, alnfile, knowns, sequence, deviation=None,
                  library_schedule=None, csrfile=None, inifile=None,
                  assess_methods=None):
-        automodel.__init__(self, env, alnfile, knowns, sequence, deviation,
+        AutoModel.__init__(self, env, alnfile, knowns, sequence, deviation,
                            library_schedule, csrfile, inifile, assess_methods)
         # Modeling won't work unless we read/write hydrogen atoms!
         self.env.io.hydrogen = True
 
 
-# Modeller 10 compatibility
-AllHModel = allhmodel
+# Modeller 9 compatibility
+from modeller.util.deprecation import _deprecation_handler
+class allhmodel(AllHModel):
+    def __init__(self, *args, **keys):
+        _deprecation_handler._init_class(allhmodel)
+        AllHModel.__init__(self, *args, **keys)
