@@ -1,7 +1,7 @@
 import _modeller
-from modeller.optimizers.builtin_optimizer import builtin_optimizer
+from modeller.optimizers.builtin_optimizer import BuiltinOptimizer
 
-class conjugate_gradients(builtin_optimizer):
+class ConjugateGradients(BuiltinOptimizer):
     """Optimize with Beale restraint conjugate gradients method"""
     _modpt = None
     __free_func = _modeller.mod_cg_optimizer_free
@@ -10,7 +10,7 @@ class conjugate_gradients(builtin_optimizer):
 
     def __init__(self, output='NO_REPORT', min_atom_shift=0.01,
                  residue_span_range=(0, 99999), **vars):
-        builtin_optimizer.__init__(self)
+        BuiltinOptimizer.__init__(self)
         self._modpt = _modeller.mod_cg_optimizer_new(self)
         self.__params = {}
         for key in ("output", "min_atom_shift", "residue_span_range"):
@@ -59,5 +59,9 @@ class conjugate_gradients(builtin_optimizer):
     gsq = property(__get_gsq, doc="Current gradient")
 
 
-# Modeller 10 compatibility
-ConjugateGradients = conjugate_gradients
+# Modeller 9 compatibility
+from modeller.util.deprecation import _deprecation_handler
+class conjugate_gradients(ConjugateGradients):
+    def __init__(self, *args, **keys):
+        _deprecation_handler._init_class(conjugate_gradients)
+        ConjugateGradients.__init__(self, *args, **keys)
