@@ -1,9 +1,10 @@
 import _modeller
 from modeller.util import modutil, modlist
-from modeller.util.modobject import modobject
-from modeller import pssmdb, residue, modfile
+from modeller.util.modobject import ModObject
+from modeller.pssmdb import PSSMDB
+from modeller import residue, modfile
 
-class profile(modobject):
+class Profile(ModObject):
     """Holds a profile of multiple sequences"""
     __modpt = None
     __free_func = _modeller.mod_profile_free
@@ -78,8 +79,8 @@ class profile(modobject):
 
     def to_alignment(self):
         """Converts the profile to alignment format"""
-        from modeller.alignment import alignment
-        aln = alignment(self.env)
+        from modeller.alignment import Alignment
+        aln = Alignment(self.env)
         _modeller.mod_profile_to_aln(prf=self.modpt, aln=aln.modpt,
                                      libs=self.env.libs.modpt)
         return aln
@@ -95,7 +96,7 @@ class profile(modobject):
         (output_score_file, output_scores) = self.__opt_file(output_score_file)
         (summary_file, write_summary) = self.__opt_file(summary_file)
         if psm is None:
-            psm = pssmdb.pssmdb(self.env)
+            psm = PSSMDB(self.env)
         func = _modeller.mod_profile_scan
         return func(self.modpt, psm.modpt, self.env.libs.modpt,
                     profile_list_file, matrix_offset, profile_format, rr_file,
@@ -206,5 +207,9 @@ class Residue(residue.Residue):
         self.type = type
 
 
-# Modeller 10 compatibility
-Profile = profile
+# Modeller 9 compatibility
+from modeller.util.deprecation import _deprecation_handler
+class profile(Profile):
+    def __init__(self, *args, **keys):
+        _deprecation_handler._init_class(profile)
+        Profile.__init__(self, *args, **keys)
