@@ -1,5 +1,5 @@
 from modeller.util.modlist import VarList
-from modeller.rigid_body import rigid_body
+from modeller.rigid_body import RigidBody
 import _modeller
 
 class RigidBodyList(VarList):
@@ -14,12 +14,12 @@ class RigidBodyList(VarList):
     def _getfunc(self, indx):
         mdl = self.__mdl
         (inds, scale) = _modeller.mod_rigid_body_get(mdl.modpt, indx)
-        p = rigid_body(*[mdl.atoms[i-1] for i in inds])
+        p = RigidBody(*[mdl.atoms[i-1] for i in inds])
         p.scale_factor = scale
         return p
     def _setfunc(self, indx, obj):
         mdl = self.__mdl
-        if not isinstance(obj, rigid_body):
-            raise TypeError("can only use rigid_body objects here")
+        if not isinstance(obj, RigidBody):
+            raise TypeError("can only use RigidBody objects here")
         _modeller.mod_rigid_body_set(mdl.modpt, indx, obj._get_base_atoms(mdl),
                                      obj.scale_factor)
