@@ -1,5 +1,5 @@
-from modeller.sequence_db import sequence_db
-from modeller.alignment import alignment
+from modeller.sequence_db import SequenceDB
+from modeller.alignment import Alignment
 
 def sequence_srch(env, sequence, segfile, chains_list,
                   toplib='${LIB}/top_heav.lib', search_randomizations=0,
@@ -14,9 +14,9 @@ def sequence_srch(env, sequence, segfile, chains_list,
     overhang=20
     seqfile = '$(LIB)/pdball.pir'
 
-    sdb = sequence_db(env, seq_database_file=seqfile, chains_list=chains_list,
-                      seq_database_format='PIR')
-    aln = alignment(env, file=segfile, align_codes=sequence)
+    sdb = SequenceDB(env, seq_database_file=seqfile, chains_list=chains_list,
+                     seq_database_format='PIR')
+    aln = Alignment(env, file=segfile, align_codes=sequence)
     sdb.search(aln, search_top_list=30, off_diagonal=9999,
                search_group_list = '$(LIB)/pdb_40.grp',
                seq_database_file=seqfile, gap_penalties_1d=penalties,
